Skip to contents

The boston_density_ridges() function uses the results_boston database to plot a density plot (based on the package "ggridges") of finishing times of Boston Marathon from 2009 to 2022. This function needs at least two years to for the graph to plotted properly.

Usage

boston_density_ridges(year, range_position)

Arguments

year

Year when the event occured (string).

range_position

Range of positions to be ploted (string).

Value

A dataframe of 5 column with year of event, full name of the athlete, age of race day, finishing position by gender and official.

Examples

boston_density_ridges(year = 2012:2019, range_position = 1:10)
#> Picking joint bandwidth of 74.7